@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::CommandOptionsFactory;
-$Footprintless::CommandOptionsFactory::VERSION = '1.0';
+$Footprintless::CommandOptionsFactory::VERSION = '1.01';
 # ABSTRACT: A factory for creating command options
 # PODNAME: Footprintless::CommandOptionsFactory
 
@@ -52,17 +52,29 @@ Footprintless::CommandOptionsFactory - A factory for creating command options
 
 =head1 VERSION
 
-version 1.0
+version 1.01
 
 =head1 DESCRIPTION
 
-This class provides a wrapper around 
-C<Footprintless::Command::command_options> that will use 
-C<Footprintless::Localhost> to determine if the hostname in the options
+This module creates 
+L<command opitons|Footprintless::Command/command_options(%options)> that will use 
+L<Footprintless::Localhost> to determine if the hostname in the options
 is an alias for localhost.  If so, it will remove hostname from the
 options to prevent network operations and allow for local implementation
 optimizations.
 
+=head1 ENTITIES
+
+There are four entites that are used for command options.  All four have
+scalar values.  Their defaults are:
+
+    hostname => undef,
+    ssh => 'ssh -q',
+    sudo_username => undef,
+    username => undef
+
+Most (if not all) modules make use of these entities.
+
 =head1 CONSTRUCTORS
 
 =head2 new(%options)
@@ -89,7 +101,8 @@ passed in to C<command_options(%options)>.  Defaults to C<ssh -q>.
 =head2 command_options(%options)
 
 Removes C<hostname> from C<%options> if it is an alias for localhost, 
-then forwards on to C<Footprintless::Command::command_options>.
+then forwards on to 
+L<Fooptintless::Command::command_options|Footprintless::Command/command_options(%options)>.
 
 =head1 AUTHOR
 
