@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Deployment;
-$Footprintless::Deployment::VERSION = '1.0';
+$Footprintless::Deployment::VERSION = '1.01';
 # ABSTRACT: A deployment manager
 # PODNAME: Footprintless::Deployment
 
@@ -32,17 +32,15 @@ sub new {
 sub clean {
     my ( $self, %options ) = @_;
 
-    return
-        unless ( $self->{spec}{configuration}{clean}
-        && @{ $self->{spec}{configuration}{clean} } );
+    return unless ( $self->{spec}{clean}
+        && @{ $self->{spec}{clean} } );
 
     my @clean;
     if ( $options{rebase} ) {
-        @clean = map { $self->_rebase( $_, $options{rebase} ) }
-            @{ $self->{spec}{configuration}{clean} };
+        @clean = map { $self->_rebase( $_, $options{rebase} ) } @{ $self->{spec}{clean} };
     }
     else {
-        @clean = @{ $self->{spec}{configuration}{clean} };
+        @clean = @{ $self->{spec}{clean} };
     }
 
     if (@clean) {
@@ -71,12 +69,12 @@ sub deploy {
     my ( $is_local, $to_dir );
 
     if ( $options{rebase} ) {
-        $to_dir = $self->_rebase( $self->{spec}{configuration}{to_dir}, $options{rebase} );
+        $to_dir = $self->_rebase( $self->{spec}{to_dir}, $options{rebase} );
         $is_local = 1;
     }
     else {
         $is_local = $self->{localhost}->is_alias( $self->{spec}{hostname} );
-        $to_dir = $is_local ? $self->{spec}{configuration}{to_dir} : $self->_temp_dir();
+        $to_dir = $is_local ? $self->{spec}{to_dir} : $self->_temp_dir();
     }
 
     my @names =
@@ -153,8 +151,10 @@ sub _push_to_destination {
 
     $self->{command_runner}->run_or_die(
         cp_command(
-            $temp_dir, $self->{spec}{configuration}{to_dir},
-            $self->_command_options(), 'status' => $status
+            $temp_dir,
+            $self->{spec}{to_dir},
+            $self->_command_options(),
+            'status' => $status
         )
     );
 }
@@ -191,7 +191,7 @@ Footprintless::Deployment - A deployment manager
 
 =head1 VERSION
 
-version 1.0
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -199,37 +199,6 @@ version 1.0
     use Footprintless;
     my $deployment = Footprintless->new()->deployment('deployment');
 
-    # Or using inline configuration
-    use Config::Entities;
-    use Footprintless::Deployment;
-    my $deployment = Footprintless::Deployment->new(
-        Config::Entities->new(
-            entities => {
-                deployment => {
-                    'Config::Entities::inherit' => ['hostname', 'sudo_username'],
-                    configuration => {
-                        clean => [
-                            '/opt/tomcat/webapps/',
-                            '/opt/tomcat/temp/',
-                            '/opt/tomcat/work/'
-                        ],
-                        to_dir => '/opt/tomcat/webapps'
-                    },
-                    resources => {
-                        bar => '/home/me/.m2/repository/com/pastdev/bar/1.2/bar-1.2.war',
-                        baz => {
-                            coordinate => 'com.pastdev:baz:war:1.0',
-                            'as' => 'foo.war',
-                            type => 'maven'
-                        }
-                    }
-                },
-                hostname => 'test.pastdev.com',
-                sudo_username => 'developer'
-            }
-        ),
-        'deployment');
-
     # Standard deploy procedure
     $deployment->clean();
     $deployment->deploy();
@@ -253,6 +222,40 @@ tomcat, a deployment might refer to all of the webapps deployed to the
 container, and the folders and files that are I<NOT> part of the tomcat
 container itself.  
 
+=head1 ENTITIES
+
+A simple deployment:
+
+    deployment => {
+        clean => ['/opt/app/'],
+        resources => {
+            foo => 'http://download.com/foo.exe',
+            bar => 'http://download.com/bar.exe'
+        },
+        to_dir => '/opt/app'
+    }
+
+A more complex situation, perhaps a tomcat instance:
+
+    deployment => {
+        'Config::Entities::inherit' => ['hostname', 'sudo_username'],
+        clean => [
+            '/opt/tomcat/conf/Catalina/localhost/',
+            '/opt/tomcat/temp/',
+            '/opt/tomcat/webapps/',
+            '/opt/tomcat/work/'
+        ],
+        resources => {
+            bar => '/home/me/.m2/repository/com/pastdev/bar/1.2/bar-1.2.war',
+            baz => {
+                coordinate => 'com.pastdev:baz:war:1.0',
+                'as' => 'foo.war',
+                type => 'maven'
+            }
+        },
+        to_dir => '/opt/tomcat/webapps'
+    }
+
 =head1 CONSTRUCTORS
 
 =head2 new($entity, $coordinate, %options)
