@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Log;
-$Footprintless::Log::VERSION = '1.0';
+$Footprintless::Log::VERSION = '1.01';
 # ABSTRACT: A log manager
 # PODNAME: Footprintless::Log
 
@@ -99,7 +99,6 @@ sub _init {
         %{  $entity->fill(
                 $coordinate,
                 {   hostname      => undef,
-                    username      => undef,
                     ssh           => undef,
                     ssh_username  => undef,
                     sudo_username => undef
@@ -192,7 +191,7 @@ Footprintless::Log - A log manager
 
 =head1 VERSION
 
-version 1.0
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -200,19 +199,7 @@ version 1.0
     use Footprintless;
     my $log = Footprintless->new()->log();
 
-    # Or using inline configuration
-    use Footprintless::Service;
-    my $log = Footprintless::Log->new(
-        Config::Entities->new({
-            entity => {
-                logs => {
-                    catalina => '/opt/tomcat/logs/catalina.out'
-                }
-            }
-        }),
-        'logs.catalina');
-
-    # Wait for tomcat to start
+    # Wait for a started message before proceeding
     $log->follow(until => qr/Started in \d+/); 
 
     # Check for errors during startup
@@ -222,6 +209,25 @@ version 1.0
 
 Provides access to read from log files.
 
+=head1 ENTITIES
+
+A log entity is simply a name/value:
+
+    catalina => '/opt/tomcat/logs/catalina.out'
+
+They will inherit all of their command options (C<hostname>, C<ssh>, 
+C<sudo_username>, C<username>)from their ancestry.  Logs are commonly 
+grouped together:
+
+    web => {
+        hostname => 'web.pastdev.com',
+        logs => {
+            error => '/var/log/httpd/error_log',
+            access => '/var/log/httpd/access_log'
+        }
+        sudo_username => 'apache'
+    }
+
 =head1 CONSTRUCTORS
 
 =head2 new($entity, $coordinate, %options)
